pub struct StringFunctionalEnrichmentArgs {
pub identifiers: Vec<String>,
pub background: Option<Vec<String>>,
pub species: usize,
pub caller_identity: String,
}Expand description
Performs the enrichment analysis of your set of proteins for the Gene Ontology, KEGG pathways, UniProt Keywords, PubMed publications, Pfam, InterPro and SMART domains.
Fields
identifiers: Vec<String>List of genes to retrieve network for
background: Option<Vec<String>>Background list of genes to compare against (Only STRING identifiers are accepted) If not provided, the whole genome of the species is used
species: usizeSpecies to retrieve network for (NCBI taxonomy ID)
caller_identity: Stringidentifier of the caller to provide to the server
Implementations
Sourceimpl StringFunctionalEnrichmentArgs
impl StringFunctionalEnrichmentArgs
Sourcepub fn builder() -> StringFunctionalEnrichmentArgsBuilder
pub fn builder() -> StringFunctionalEnrichmentArgsBuilder
Create an instance of StringFunctionalEnrichmentArgs using the builder syntax
Sourceimpl StringFunctionalEnrichmentArgs
impl StringFunctionalEnrichmentArgs
pub fn build_post(&self) -> Value