pub struct StringInteractionsArgs {
pub identifiers: Vec<String>,
pub species: usize,
pub limit: Option<usize>,
pub required_score: Option<f64>,
pub network_type: StringNetworkType,
pub caller_identity: String,
}Expand description
Gets all the STRING interaction partners of your proteins
Fields
identifiers: Vec<String>List of genes to retrieve network for
species: usizeSpecies to retrieve network for (NCBI taxonomy ID)
limit: Option<usize>limits the number of interaction partners retrieved per protein (most confident interactions come first) default set by the server (usually 10)
required_score: Option<f64>threshold of significance to include a interaction, a number between 0 and 1000 (default depends on the network)
network_type: StringNetworkTypeThe type of network to retrieve
caller_identity: Stringidentifier of the caller to provide to the server
Implementations
Sourceimpl StringInteractionsArgs
impl StringInteractionsArgs
Sourcepub fn builder() -> StringInteractionsArgsBuilder
pub fn builder() -> StringInteractionsArgsBuilder
Create an instance of StringInteractionsArgs using the builder syntax
Sourceimpl StringInteractionsArgs
impl StringInteractionsArgs
pub fn build_post(&self) -> Value