pub struct StringMappingArgs {
pub identifiers: Vec<String>,
pub echo_query: bool,
pub limit: Option<usize>,
pub species: usize,
pub caller_identity: String,
}Fields
identifiers: Vec<String>List of genes to retrieve network for
echo_query: boolinsert column with your input identifier
limit: Option<usize>limits the number of matches per query identifier (best matches come first)
species: usizeSpecies to retrieve network for (NCBI taxonomy ID)
caller_identity: Stringidentifier of the caller to provide to the server
Implementations
Sourceimpl StringMappingArgs
impl StringMappingArgs
Sourcepub fn builder() -> StringMappingArgsBuilder
pub fn builder() -> StringMappingArgsBuilder
Create an instance of StringMappingArgs using the builder syntax
Sourceimpl StringMappingArgs
impl StringMappingArgs
pub fn build_post(&self) -> Value