pub struct StringNetworkArgs {
pub identifiers: Vec<String>,
pub species: usize,
pub required_score: Option<f64>,
pub network_type: StringNetworkType,
pub add_nodes: Option<usize>,
pub show_query_node_labels: bool,
pub caller_identity: String,
}Expand description
Retrieves the network interactions for your input protein(s) in various text based formats
Fields
identifiers: Vec<String>List of genes to retrieve network for
species: usizeSpecies to retrieve network for (NCBI taxonomy ID)
required_score: Option<f64>threshold of significance to include a interaction, a number between 0 and 1000 (default depends on the network)
network_type: StringNetworkTypeThe type of network to retrieve
add_nodes: Option<usize>adds a number of proteins with to the network based on their confidence score
show_query_node_labels: boolwhen available use submitted names in the preferredName column when true
caller_identity: Stringidentifier of the caller to provide to the server
Implementations
Sourceimpl StringNetworkArgs
impl StringNetworkArgs
Sourcepub fn builder() -> StringNetworkArgsBuilder
pub fn builder() -> StringNetworkArgsBuilder
Create an instance of StringNetworkArgs using the builder syntax
Sourceimpl StringNetworkArgs
impl StringNetworkArgs
pub fn build_post(&self) -> Value